---
title: <span class="badge object-type-scalar"></span> Ohm
---
# <span class="badge object-type-scalar"></span> Ohm

Energy: Ohm (Ω)

## Definition

```python
# Energy: Ohm (Ω)
Ohm: typing.Literal["ohm"] = "ohm"
```
